@@ -19,20 +19,28 @@ build_favicons <- function(pkg = ".", overwrite = FALSE) {
   rlang::check_installed("openssl")
   pkg <- as_pkgdown(pkg)
 
-  rule("Building favicons")
+  cli::cli_rule("Building favicons")
 
   logo_path <- find_logo(pkg$src_path)
 
   if (is.null(logo_path)) {
-    stop("Can't find package logo PNG or SVG to build favicons.", call. = FALSE)
+    cli::cli_abort(c(
+      "Can't find package logo PNG or SVG to build favicons.",
+      "i" = "See {.fun usethis::use_logo} for more information."
+    ))
   }
 
   if (has_favicons(pkg) && !overwrite) {
-    message("Favicons already exist in `pkgdown/`. Set `overwrite = TRUE` to re-create.")
+    cli::cli_inform(c(
+      "Favicons already exist in {.path pkgdown}",
+      "i" = "Set {.code overwrite = TRUE} to re-create."
+    ))
     return(invisible())
   }
 
-  message("Building favicons with realfavicongenerator.net...")
+  cli::cli_inform(c(
+    i = "Building favicons with {.url https://realfavicongenerator.net} ..."
+  ))
 
   logo <- readBin(logo_path, what = "raw", n = fs::file_info(logo_path)$size)
 
@@ -66,18 +74,14 @@ build_favicons <- function(pkg = ".", overwrite = FALSE) {
     quiet = TRUE
   )
   if (httr::http_error(resp)) {
-    stop("API request failed.", call. = FALSE)
+    cli::cli_abort("API request failed.", call = caller_env())
   }
 
   content <- httr::content(resp)
   result <- content$favicon_generation_result
 
   if (!identical(result$result$status, "success")) {
-    stop(
-      "API request failed. ", "
-      Please submit bug report to <https://github.com/r-lib/pkgdown/issues>",
-      call. = FALSE
-    )
+    cli::cli_abort("API request failed.", .internal = TRUE)
   }
 
   tmp <- tempfile()
@@ -93,27 +97,15 @@ build_favicons <- function(pkg = ".", overwrite = FALSE) {
     utils::unzip(tmp, exdir = path(pkg$src_path, "pkgdown", "favicon"))
   },
   warning = function(e) {
-    stop("Your logo file couldn't be processed and may be corrupt.", call. = FALSE)
+    cli::cli_abort("Your logo file couldn't be processed and may be corrupt.", parent = e)
   },
   error = function(e) {
-    stop("Your logo file couldn't be processed and may be corrupt.", call. = FALSE)
+    cli::cli_abort("Your logo file couldn't be processed and may be corrupt.", parent = e)
   })
 
   invisible()
 }
 
-#' Deprecated as of pkgdown 1.4.0
-#' @rdname build_favicons
-#' @inheritParams build_favicons
-#' @export
-build_favicon <- function(pkg, overwrite) {
-  message(
-    "`build_favicon()` is deprecated as of pkgdown 1.4.0. ",
-    "Please use `build_favicons()` instead."
-  )
-  build_favicons(pkg, overwrite)
-}
-
 copy_favicons <- function(pkg = ".") {
   pkg <- as_pkgdown(pkg)
 
