@@ -129,7 +129,7 @@ author_list <- function(x, authors_info = NULL, comment = FALSE, pkg) {
   list(
     name = name,
     roles = roles,
-    comment = x$comment,
+    comment = linkify(x$comment),
     orcid = orcid_link(orcid)
   )
 }
@@ -186,8 +186,8 @@ role_lookup <- function(abbr) {
 
   out <- unname(roles[abbr])
   if (any(is.na(out))) {
-    missing <- paste0("'", abbr[is.na(out)], "'", collapse = ", ")
-    warn(paste0("Unknown MARC role abbreviation ", missing))
+    missing <- abbr[is.na(out)]
+    cli::cli_warn("Unknown MARC role abbreviation{?s}: {.field {missing}}")
     out[is.na(out)] <- abbr[is.na(out)]
   }
   out
