@@ -187,14 +187,14 @@ build_reference <- function(pkg = ".",
     topics <- purrr::transpose(pkg$topics)
   }
 
-  purrr::map(
+  unwrap_purrr_error(purrr::map(
     topics,
     build_reference_topic,
     pkg = pkg,
     lazy = lazy,
     examples_env = examples_env,
     run_dont_run = run_dont_run
-  )
+  )) 
 
   preview_site(pkg, "reference", preview = preview)
 }
@@ -245,7 +245,7 @@ examples_env <- function(pkg, seed = 1014L, devel = TRUE, envir = parent.frame()
 #' @rdname build_reference
 build_reference_index <- function(pkg = ".") {
   pkg <- section_init(pkg, depth = 1L)
-  dir_create(path(pkg$dst_path, "reference"))
+  create_subdir(pkg, "reference")
 
   # Copy icons, if needed
   src_icons <- path(pkg$src_path, "icons")
@@ -268,7 +268,7 @@ build_reference_topic <- function(topic,
                                   pkg,
                                   lazy = TRUE,
                                   examples_env = globalenv(),
-                                  run_dont_run = FALSE ) {
+                                  run_dont_run = FALSE) {
 
   in_path <- path(pkg$src_path, "man", topic$file_in)
   out_path <- path(pkg$dst_path, "reference", topic$file_out)
@@ -286,7 +286,11 @@ build_reference_topic <- function(topic,
       run_dont_run = run_dont_run
     ),
     error = function(err) {
-      cli::cli_abort("Failed to parse Rd in {.file {topic$file_in}}", parent = err)
+      cli::cli_abort(
+        "Failed to parse Rd in {.file {topic$file_in}}", 
+        parent = err,
+        call = quote(build_reference())
+      )
     }
   )
 
