@@ -24,12 +24,28 @@ as_pkgdown <- function(pkg = ".", override = list()) {
   meta <- read_meta(pkg)
   meta <- modify_list(meta, override)
 
-  bs_version <- get_bootstrap_version(list(meta = meta))
+  # A local Bootstrap version, when provided, may drive the template choice
+  config_path <- pkgdown_config_path(pkg)
+  config_path <- if (!is.null(config_path)) fs::path_rel(config_path, pkg)
+  bs_version_local <- get_bootstrap_version(
+    template = meta$template,
+    config_path = config_path
+  )
 
   template_config <- find_template_config(
     package = meta$template$package,
-    bs_version = bs_version
+    bs_version = bs_version_local
   )
+
+  bs_version_template <-
+    if (is.null(bs_version_local)) {
+      get_bootstrap_version(
+        template = template_config$template,
+        config_path = config_path,
+        package = meta$template$package
+      )
+    }
+
   meta <- modify_list(template_config, meta)
 
   # Ensure the URL has no trailing slash
@@ -40,6 +56,12 @@ as_pkgdown <- function(pkg = ".", override = list()) {
   package <- desc$get_field("Package")
   version <- desc$get_field("Version")
 
+  # Check the final Bootstrap version, possibly filled in by template pkg
+  bs_version <- check_bootstrap_version(
+    bs_version_local %||% bs_version_template,
+    pkg
+  )
+
   development <- meta_development(meta, version, bs_version)
 
   if (is.null(meta$destination)) {
@@ -98,26 +120,41 @@ read_desc <- function(path = ".") {
   desc::description$new(path)
 }
 
-get_bootstrap_version <- function(pkg) {
-  template_bootstrap <- pkg$meta[["template"]]$bootstrap
-  template_bslib <- pkg$meta[["template"]]$bslib$version
+get_bootstrap_version <- function(template, config_path = NULL, package = NULL) {
+  if (is.null(template)) {
+    return(NULL)
+  }
+
+  template_bootstrap <- template[["bootstrap"]]
+  template_bslib <- template[["bslib"]][["version"]]
 
   if (!is.null(template_bootstrap) && !is.null(template_bslib)) {
+    instructions <-
+      if (!is.null(package)) {
+        paste0(
+          "Update the pkgdown config in {.pkg ", package, "}, ",
+          "or set a Bootstrap version in your {.file ",
+          if (is.null(config_path)) "_pkgdown.yml" else config_path,
+          "}."
+        )
+      } else if (!is.null(config_path)) {
+        paste("Remove one of them from {.file", config_path, "}")
+      }
+
     cli::cli_abort(
       c(
         sprintf(
           "Both {.field %s} and {.field %s} are set.",
-          pkgdown_field(pkg, c("template", "bootstrap")),
-          pkgdown_field(pkg, c("template", "bslib", "version"))
+          pkgdown_field(list(), c("template", "bootstrap")),
+          pkgdown_field(list(), c("template", "bslib", "version"))
         ),
-        x = "Remove one of them from {.file {pkgdown_config_relpath(pkg)}}"
+        i = instructions
       ),
       call = caller_env()
     )
   }
 
-  version <- template_bootstrap %||% template_bslib
-  check_bootstrap_version(version, pkg)
+  template_bootstrap %||% template_bslib
 }
 
 check_bootstrap_version <- function(version, pkg) {
