@@ -148,47 +148,51 @@ data_open_graph <- function(pkg = ".") {
 
 check_open_graph <- function(og) {
   if (!is.list(og)) {
-    abort(paste("`opengraph` must be a list, not", friendly_type_of(og)))
+    fog <- friendly_type_of(og)
+    cli::cli_abort(
+      "{.var opengraph} must be a list, not {.val fog}.",
+      call = caller_env()
+    )
   }
   supported_fields <- c("image", "twitter")
   unsupported_fields <- setdiff(names(og), supported_fields)
   if (length(unsupported_fields)) {
-    warn(paste0(
-      "Unsupported `opengraph` field(s): ",
-      paste(unsupported_fields, collapse = ", ")
-    ))
+    cli::cli_warn(
+      "Unsupported {.var opengraph} field{?s}: {.val unsupported_fields}."
+    )
   }
   if ("twitter" %in% names(og)) {
     if (is.character(og$twitter) && length(og$twitter) == 1 && grepl("^@", og$twitter)) {
-      abort(paste(
-        "The `opengraph: twitter` option must be a list. Did you mean this?",
-        "opengraph:",
-        "  twitter:",
-        paste("    creator:", og$twitter),
-        sep = "\n"
-      ))
+      cli::cli_abort(
+        "The {.var opengraph: twitter} option must be a list.",
+        call = caller_env()
+      )
     }
     if (!is.list(og$twitter)) {
-      abort("The `opengraph: twitter` option must be a list.")
+      cli::cli_abort(
+        "The {.var opengraph: twitter} option must be a list.",
+        call = caller_env()
+      )
     }
     if (is.null(og$twitter$creator) && is.null(og$twitter$site)) {
-      abort(
-        "The `opengraph: twitter` option must include either 'creator' or 'site'."
+      cli::cli_abort(
+        "{.var opengraph: twitter} must include either {.val creator} or {.val site}.",
+        call = caller_env()
       )
     }
   }
   if ("image" %in% names(og)) {
     if (is.character(og$image) && length(og$image) == 1) {
-      abort(paste(
-        "The `opengraph: image` option must be a list. Did you mean this?",
-        "opengraph",
-        "  image:",
-        paste("    src:", og$image),
-        sep = "\n"
-      ))
+      cli::cli_abort(
+        "The {.var opengraph: image} option must be a list.",
+        call = caller_env()
+      )
     }
     if (!is.list(og$image)) {
-      abort("The `opengraph: image` option must be a list.")
+      cli::cli_abort(
+        "The {.var opengraph: image} option must be a list.",
+        call = caller_env()
+      )
     }
   }
   og[intersect(supported_fields, names(og))]
@@ -208,7 +212,7 @@ write_if_different <- function(pkg, contents, path, quiet = FALSE, check = TRUE)
 
   if (check && !made_by_pkgdown(full_path)) {
     if (!quiet) {
-      message("Skipping '", path, "': not generated by pkgdown")
+      cli::cli_inform("Skipping {.file {path}}: not generated by pkgdown")
     }
     return(FALSE)
   }
@@ -221,8 +225,9 @@ write_if_different <- function(pkg, contents, path, quiet = FALSE, check = TRUE)
   }
 
   if (!quiet) {
-    cat_line("Writing ", dst_path(path))
+    writing_file(path_rel(full_path, pkg$dst_path), path)
   }
+
   write_lines(contents, path = full_path)
   TRUE
 }
