@@ -8,7 +8,7 @@ test_that("simple tags translated to known good values", {
   expect_equal(rd2html("\\ldots"), "...")
   expect_equal(rd2html("\\dots"), "...")
   expect_equal(rd2html("\\R"), "<span style=\"R\">R</span>")
-  expect_equal(rd2html("\\cr"), "<br />")
+  expect_equal(rd2html("\\cr"), "<br>")
 
   "Macros"
   expect_equal(rd2html("\\newcommand{\\f}{'f'} \\f{}"), "'f'")
@@ -25,10 +25,13 @@ test_that("simple wrappers work as expected", {
 })
 
 test_that("subsection generates h3", {
-  expect_snapshot(cat_line(rd2html("\\subsection{A}{B}")))
+  local_edition(3)
+  expect_snapshot(cli::cat_line(rd2html("\\subsection{A}{B}")))
 })
+
 test_that("subsection generates h3", {
-  expect_snapshot(cat_line(rd2html("\\subsection{A}{
+  local_edition(3)
+  expect_snapshot(cli::cat_line(rd2html("\\subsection{A}{
     p1
 
     p2
@@ -45,7 +48,8 @@ test_that("subsection generates generated anchor", {
 })
 
 test_that("nested subsection generates h4", {
-  expect_snapshot(cat_line(rd2html("\\subsection{H3}{\\subsection{H4}{}}")))
+  local_edition(3)
+  expect_snapshot(cli::cat_line(rd2html("\\subsection{H3}{\\subsection{H4}{}}")))
 })
 
 test_that("if generates html", {
@@ -80,7 +84,7 @@ test_that("support platform specific code", {
 
 # tables ------------------------------------------------------------------
 
-test_that("tabular genereates complete table html", {
+test_that("tabular generates complete table html", {
   table <- "\\tabular{ll}{a \\tab b \\cr}"
   expectation <- c("<table class='table'>", "<tr><td>a</td><td>b</td></tr>", "</table>")
   expect_equal(rd2html(table), expectation)
@@ -171,8 +175,10 @@ test_that("Sexprs with multiple args are parsed", {
 })
 
 test_that("Sexprs with multiple args are parsed", {
+  skip_if_not(getRversion() >= "4.0.0")
+  local_edition(3)
   local_context_eval()
-  expect_error(rd2html("\\Sexpr[results=verbatim]{1}"), "not yet supported")
+  expect_snapshot(rd2html("\\Sexpr[results=verbatim]{1}"), error = TRUE)
 })
 
 test_that("Sexprs in file share environment", {
@@ -278,6 +284,7 @@ test_that("link to non-existing functions return label", {
 })
 
 test_that("bad specs throw errors", {
+  local_edition(3)
   expect_snapshot(error = TRUE, {
     rd2html("\\url{}")
     rd2html("\\url{a\nb}")
@@ -328,7 +335,7 @@ test_that("nl after tag doesn't trigger paragraphs", {
 
 test_that("cr generates line break", {
   out <- flatten_para(rd_text("a \\cr b"))
-  expect_equal(out, "<p>a <br /> b</p>")
+  expect_equal(out, "<p>a <br> b</p>")
 })
 
 
@@ -455,3 +462,8 @@ test_that("figures are converted to img", {
     "<img src='figures/a' height=1 />"
   )
 })
+
+test_that("figures with multilines alternative text can be parsed", {
+  expect_equal(rd2html("\\figure{a}{blabla
+    blop}"), "<img src='figures/a' alt='blabla blop' />")
+})
