@@ -21,6 +21,11 @@ test_that("can parse function/methods", {
   expect_equal(usage$name, "f")
   expect_equal(usage$signature, "bar")
 
+  usage <- parse_usage("\\S3method{f}{`foo bar`}(x)")[[1]]
+  expect_equal(usage$type, "s3")
+  expect_equal(usage$name, "f")
+  expect_equal(usage$signature, "foo bar")
+
   usage <- parse_usage("\\S4method{f}{bar,baz}(x)")[[1]]
   expect_equal(usage$type, "s4")
   expect_equal(usage$name, "f")
@@ -36,6 +41,11 @@ test_that("can parse function/methods", {
   expect_equal(usage$name, "f")
   expect_equal(usage$signature, c("function", "function"))
 
+  usage <- parse_usage("\\S4method{f}{function,foo bar}(x, y)")[[1]]
+  expect_equal(usage$type, "s4")
+  expect_equal(usage$name, "f")
+  expect_equal(usage$signature, c("function", "foo bar"))
+
   usage <- parse_usage("pkg::func()")[[1]]
   expect_equal(usage$type, "fun")
   expect_equal(usage$name, "func")
